@@ -1,10 +1,10 @@
-/* $Id: initterm-r0drv-linux.c 100874 2015-06-09 14:01:31Z bird $ */
+/* $Id: initterm-r0drv-linux.c 118412 2017-10-17 14:26:02Z bird $ */
 /** @file
  * IPRT - Initialization & Termination, R0 Driver, Linux.
  */
 
 /*
- * Copyright (C) 2006-2015 Oracle Corporation
+ * Copyright (C) 2006-2017 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -25,9 +25,9 @@
  */
 
 
-/*******************************************************************************
-*   Header Files                                                               *
-*******************************************************************************/
+/*********************************************************************************************************************************
+*   Header Files                                                                                                                 *
+*********************************************************************************************************************************/
 #include "the-linux-kernel.h"
 #include "internal/iprt.h"
 #include <iprt/err.h>
@@ -35,9 +35,9 @@
 #include "internal/initterm.h"
 
 
-/*******************************************************************************
-*   Global Variables                                                           *
-*******************************************************************************/
+/*********************************************************************************************************************************
+*   Global Variables                                                                                                             *
+*********************************************************************************************************************************/
 /** The IPRT work queue. */
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 41)
 static struct workqueue_struct *g_prtR0LnxWorkQueue;
@@ -46,9 +46,9 @@ static DECLARE_TASK_QUEUE(g_rtR0LnxWorkQueue);
 #endif
 
 
-/*******************************************************************************
-*   Internal Functions                                                         *
-*******************************************************************************/
+/*********************************************************************************************************************************
+*   Internal Functions                                                                                                           *
+*********************************************************************************************************************************/
 /* in alloc-r0drv0-linux.c */
 DECLHIDDEN(void) rtR0MemExecCleanup(void);
 
@@ -62,6 +62,8 @@ DECLHIDDEN(void) rtR0MemExecCleanup(void);
  */
 DECLHIDDEN(void) rtR0LnxWorkqueuePush(RTR0LNXWORKQUEUEITEM *pWork, void (*pfnWorker)(RTR0LNXWORKQUEUEITEM *))
 {
+    IPRT_LINUX_SAVE_EFL_AC();
+
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 41)
 # if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 20)
     INIT_WORK(pWork, pfnWorker);
@@ -73,6 +75,8 @@ DECLHIDDEN(void) rtR0LnxWorkqueuePush(RTR0LNXWORKQUEUEITEM *pWork, void (*pfnWor
     INIT_TQUEUE(pWork, (void (*)(void *))pfnWorker, pWork);
     queue_task(pWork, &g_rtR0LnxWorkQueue);
 #endif
+
+    IPRT_LINUX_RESTORE_EFL_AC();
 }
 
 
@@ -84,16 +88,23 @@ DECLHIDDEN(void) rtR0LnxWorkqueuePush(RTR0LNXWORKQUEUEITEM *pWork, void (*pfnWor
  */
 DECLHIDDEN(void) rtR0LnxWorkqueueFlush(void)
 {
+    IPRT_LINUX_SAVE_EFL_AC();
+
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 41)
     flush_workqueue(g_prtR0LnxWorkQueue);
 #else
     run_task_queue(&g_rtR0LnxWorkQueue);
 #endif
+
+    IPRT_LINUX_RESTORE_EFL_AC();
 }
 
 
 DECLHIDDEN(int) rtR0InitNative(void)
 {
+    int rc = VINF_SUCCESS;
+    IPRT_LINUX_SAVE_EFL_AC();
+
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 41)
  #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 13)
     g_prtR0LnxWorkQueue = create_workqueue("iprt-VBoxWQueue");
@@ -101,15 +112,18 @@ DECLHIDDEN(int) rtR0InitNative(void)
     g_prtR0LnxWorkQueue = create_workqueue("iprt-VBoxQ");
  #endif
     if (!g_prtR0LnxWorkQueue)
-        return VERR_NO_MEMORY;
+        rc = VERR_NO_MEMORY;
 #endif
 
-    return VINF_SUCCESS;
+    IPRT_LINUX_RESTORE_EFL_AC();
+    return rc;
 }
 
 
 DECLHIDDEN(void) rtR0TermNative(void)
 {
+    IPRT_LINUX_SAVE_EFL_AC();
+
     rtR0LnxWorkqueueFlush();
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 41)
     destroy_workqueue(g_prtR0LnxWorkQueue);
@@ -117,5 +131,7 @@ DECLHIDDEN(void) rtR0TermNative(void)
 #endif
 
     rtR0MemExecCleanup();
+
+    IPRT_LINUX_RESTORE_EFL_AC();
 }
 
